@@ -1,15 +1,18 @@
+from .DepthChart import DepthChart
 from .Draft import Draft
 from .DraftMetadata import DraftMetadata
 from .DraftPick import DraftPick
 from .DraftSettings import DraftSettings
 from .FAABTransaction import FAABTransaction
 from .FromPlayoffMatchup import FromPlayoffMatchup
+from .Game import Game
 from .League import League
 from .LeagueSettings import LeagueSettings
 from .Matchup import Matchup
 from .Player import Player
 from .PlayerDraftPick import PlayerDraftPick
 from .PlayerDraftPickMetadata import PlayerDraftPickMetadata
+from .PlayerStats import PlayerStats
 from .PlayerTrend import PlayerTrend
 from .PlayoffMatchup import PlayoffMatchup
 from .Roster import Roster
